@@ -1,14 +1,13 @@
 #!/usr/bin/env perl
 
-use Mojolicious::Lite;
+use Mojolicious::Lite -signatures;
 use Mojo::Redis2;
-use experimental 'signatures';
 
 helper redis => sub { state $r = Mojo::Redis2->new };
 
 get '/' => 'chat';
 
-websocket '/socket' => sub ($c, $r=$c->redis) {
+websocket '/socket' => sub ($c, $r = $c->redis) {
   $r->subscribe(['chat']);
   my $cb = $r->on(message => sub ($r, $msg, $chan) { $c->send($msg) });
   $c->on(finish => sub { $r->unsubscribe(message => $cb) });
